@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -726,7 +726,13 @@ sub translate_msg {
 sub TO_JSON {
 	my ($self) = @_;
 
-	return { %{$self} };
+	my %copy = %{$self};
+	delete $copy{arrival_wings};
+	delete $copy{departure_wings};
+	delete $copy{replaced_by};
+	delete $copy{replacement_for};
+
+	return { %copy };
 }
 
 1;
@@ -752,7 +758,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
